@@ -17,5 +17,8 @@
 pub mod field;
 pub use field::*;
 
+pub mod from_field_elements;
+pub use from_field_elements::*;
+
 pub mod to_constraint_field;
 pub use to_constraint_field::*;
